@@ -145,7 +145,8 @@ class SmartProxyView(View):
 
         # Apply request decorators, if provided
         for decorator in self.request_decorators:
-            current_request = decorator(current_request)
+            current_request = decorator(current_request,
+                                        session=request.session)
 
         # Return the SmartProxyRequest object
         return current_request
